@@ -6,7 +6,6 @@ from putils.types import Dict
 from kiss.core.exceptions import *
 from kiss.core.events import Eventer
 import traceback
-import events
 import inspect
 
 
@@ -50,14 +49,14 @@ class Router(Singleton):
 			if mtch:
 				request.params = mtch.groupdict()
 				try:
-					self.eventer.publish(events.BeforeControllerAction, request)
+					self.eventer.publish("BeforeControllerAction", request)
 					#check if controller has method for all requests
 					if hasattr(controller, "process") and inspect.ismethod(getattr(controller, "process")):
 						action = getattr(controller, "process")
 					else:
 						action = getattr(controller, request.method.lower())
 					response = action(request)
-					self.eventer.publish(events.AfterControllerAction, request, response)
+					self.eventer.publish("AfterControllerAction", request, response)
 					if not response:
 						break
 					return response
