@@ -9,11 +9,11 @@ from kiss.controllers.router import Router
 from kiss.views.core import Request, Response
 from beaker.middleware import SessionMiddleware
 from werkzeug.wsgi import SharedDataMiddleware
-from kiss.core.events import *
 from kiss.views.static import StaticBuilder
 from kiss.views.core import Templater
 from kiss.models import metadata
 import logging
+from kiss.core.events import Eventer
 
 
 class Application(Singleton):
@@ -26,17 +26,17 @@ class Application(Singleton):
 		self.init_eventer()
 		self.init_router()
 		self.init_templater()
-		self.eventer.publish(BeforeDatabaseEngineConfiguration, self)
+		self.eventer.publish("BeforeDatabaseEngineConfiguration", self)
 		self.init_db()
-		self.eventer.publish(AfterDatabaseEngineConfiguration, self)
+		self.eventer.publish("AfterDatabaseEngineConfiguration", self)
 		self.init_session()
-		self.eventer.publish(BeforeInitStatic, self)
+		self.eventer.publish("BeforeInitStatic", self)
 		self.init_static()
-		self.eventer.publish(AfterInitStatic, self)
-		self.eventer.publish(BeforeInitServer, self)
+		self.eventer.publish("AfterInitStatic", self)
+		self.eventer.publish("BeforeInitServer", self)
 		self.init_server()
-		self.eventer.publish(AfterInitServer, self)
-		self.eventer.publish(BeforeApplicationStarted, self)
+		self.eventer.publish("AfterInitServer", self)
+		self.eventer.publish("BeforeApplicationStarted", self)
 	
 	def init_options(self, options):
 		logging.basicConfig(level=logging.CRITICAL)
@@ -123,15 +123,15 @@ class Application(Singleton):
 	def start(self):
 		gevent.signal(signal.SIGTERM, self.stop)
 		gevent.signal(signal.SIGINT, self.stop)
-		self.eventer.publish(ApplicationStarted, self)
+		self.eventer.publish("ApplicationStarted", self)
 		self.server.serve_forever()
 		
 	def start_no_wait(self):
-		self.eventer.publish(ApplicationStarted, self)
+		self.eventer.publish("ApplicationStarted", self)
 		self.server.start()
 		
 	def stop(self):
-		self.eventer.publish(ApplicationStopped, self)
+		self.eventer.publish("ApplicationStopped", self)
 		self.server.stop()
 		if self.db_engine:
 			self.db_engine.close()
